// SPDX-License-Identifier: GPL-3.0-or-later

pub mod widgets;
pub mod window;
